/*
 * Copyright (C) 2000 Richard Groult <rgroult@jalix.org>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include "imagefileiconitem.h"

#include "imageloader.h"
#include "directory.h"
#include "imageviewer.h"
#include "imagelistview.h"
#include "imagefileinfo.h"
#include "exif.h"

#include <qdragobject.h>
#include <qdropsite.h>
#include <qlistview.h>
#include <qstring.h>
#include <qfile.h>
#include <qpopupmenu.h>
#include <qfileinfo.h>
#include <qdir.h>
#include <qapplication.h>
#include <qdragobject.h>
#include <qmessagebox.h>
#include <qlabel.h>
#include <qmessagebox.h>
#include <qiconview.h>
#include <qpixmapcache.h>
#include <qurloperator.h>
#include <qregexp.h>

#include <kiconloader.h>
#include <kfilemetainfo.h>
#include <kapplication.h>
#include <kpixmap.h>
#include <klocale.h>
#include <kmessagebox.h>
#include <kglobalsettings.h>
#include <konq_operations.h>
#include <kio/job.h>

ImageFileIconItem::ImageFileIconItem (ImageListView * parent,
				Directory * parentDir,
				const char *filename,
				const char *path,
				ImageViewer *iv,
				QString *description):
   FileIconItem (parent, path, filename, "image", iv),
   f(filename)
{
	this->parentDir = parentDir;
	this->description=description;

	QIconViewItem::setText(f.name());

	readable = TRUE;
	selected = false;

	full.append (path);
	full.append (filename);

	setRenameEnabled(false);

	info = new QFileInfo (full);

	size = new QString ();
	size->sprintf ("%020d", info->size ());

	QDateTime epoch( QDate( 1980, 1, 1 ) );
	date = new QString ();
	date->sprintf("%08d", epoch.secsTo(info->lastModified())) ;

	extension = new QString (info->extension().lower()+"Z"+QString(full));

	type = new QString ("file");

	pixLoad = false;
	doPreload = true;
	setName("ImageFileIconItem");

	setPixmap(BarIcon(fileInfo()->iconName(), imageList->currentIconSize));
	__isimage__ = ((fileInfo()->mimetype().left(5)=="image") || (info->extension().lower()=="mng"));
	__ismovable__=__isimage__;
}   

ImageFileIconItem::~ImageFileIconItem ()
{
}  

void
ImageFileIconItem::setText( const QString & text )
{
	if(text==this->text())
		return;

	QFileInfo *itemFileInfo = new QFileInfo( full );
	QDir dir( itemFileInfo->dir() );

	if(QFileInfo(itemFileInfo->dirPath(TRUE)+"/"+text).exists())
	{
		KMessageBox::error(iv, QString().sprintf(i18n("<br>The file '<b>%s</b>' already exists"),(const char*)text));
		delete itemFileInfo;
		return;
	}

	if ( dir.rename( itemFileInfo->fileName(), text ) )
	{
		QString itemFileName = itemFileInfo->dirPath( TRUE ) + "/" + text;
		full = QCString(itemFileInfo->dirPath( TRUE ) + "/" + text);

		delete itemFileInfo;
		itemFileInfo = new QFileInfo( itemFileName );

		f.setName(text);
		QIconViewItem::setText( this->text() );
	}
	else
	{
		KMessageBox::error(iv, QString().sprintf(i18n("<br>The file <b>%s</b> can't be renamed"), (const char*)text));
	}
	delete itemFileInfo;
}  

bool
ImageFileIconItem::suppression (bool suprFile)
{
	if (suprFile)
		return suppression ();
	else
	{
		parentDir->removeImage (this);
		return true;
	}
}   

bool
ImageFileIconItem::suppression ()
{
	if (QDir().remove (fullName ()))
	{
		parentDir->removeImage (this);
		return true;
	}
	else
	{
		return false;
	}
}   

bool
ImageFileIconItem::moveToTrash()
{
	KURL org("file:/"+fullName()), dest("file:/"+KGlobalSettings::trashPath()+getFullName(new QString(fullName())));
	KIO::file_move(org, dest, -1, true, false, false);
	return suppression(false);
}

bool
ImageFileIconItem::shred()
{
	KIO::del(KURL("file:/"+fullName ()), true, false);
	suppression(false);
	return true;
}  

QString
ImageFileIconItem::fullName ()
{
	return full;
}  

QString
ImageFileIconItem::shrink(QString str, int len) const
{
	if(str.length()<=(unsigned int)len)
		return str;
	else
	{
		return str.left(len/2) + "..." + str.right(len/2);
	}
}

QString
ImageFileIconItem::toolTipStr() const
{
	QString tip;
	ImageFileInfo iminfo((const char*)full, IMAGE, true);

	tip.sprintf("<qt><table><tr><td>"+i18n("<b>name</b>: %s<br><b>location</b>: %s<br>%s%s")+"</td></tr></table>",
		(const char*)f.name(),
		(const char*)shrink(parentDir->fullName()),
		(const char*)(QFileInfo(full).extension().lower()=="jpg"?i18n("<b>dimension</b>: ")+ProcessFile((const char*)full,true):QString()),
		(const char*)(iminfo.hasInfo()?i18n("<br><b>description</b>: <u>")+ iminfo.getTitle()+"</u>":QString()));
	tip+=fileInfo()->getToolTipText();
	return tip;
}

QString
ImageFileIconItem::text (int column) const
{

	if (column == 0)
		return KIconViewItem::text();
	else if (column == 1)
		return (*extension);
	else if (column == 2)
		return (*size);
	else if (column == 3)
		return (*type);
	else
		return QString ();

}

